<?php

/**
 * @file stormproject_extension.theme.inc
 *
 * theme functions for module stormproject_extension
 */


function theme_stormproject_extension_list($header, $projects) {
  drupal_add_css(drupal_get_path('module', 'storm') .'/storm.css', 'module');

  $rows = array();
  foreach ($projects as $key => $project) {

    $row = array();
    //$row[] = storm_icon('projectcategory_'. $project->projectcategory, $project->projectcategory);
    $row[] = l($project->nid, 'node/'. $project->nid);
    $row[] = l($project->organization_title, 'node/'. $project->organization_nid);
    $row[] = l($project->title, 'node/'. $project->nid) . theme('mark', node_mark($project->nid, $project->changed));
    $row[] = storm_icon('priority_'. check_plain($project->projectpriority), storm_attribute_value('Project priority', $project->projectpriority));
    $row[] = storm_icon('status_'. check_plain($project->projectstatus), storm_attribute_value('Project status', $project->projectstatus));
    
    if (!empty($project->datebegin)) {
      $row[] = array('data' => storm_contrib_common_time_to_date($project->datebegin, storm_contrib_common_get_custom_display_date_format()));
    }
    else {
      $row[] = array('data' => ' ');
    }
    
    if (!empty($project->dateend)) {
      $row[] = array('data' => storm_contrib_common_time_to_date($project->dateend, storm_contrib_common_get_custom_display_date_format()));
    }
    else {
      $row[] = array('data' => ' ');
    }
    
    $tmp = '<table class="stormproject-extension-duration-tb" style="margin:0; width:55px"><tr><td style="text-align:right; padding:0px" class="stormproject-extension-duration">'.theme('storm_contrib_common_number_format', $project->duration).'</td>';
    $tmp.= '<td style="text-align:left; padding: 0 0 0 3px" class="stormproject-extension-durationunit">'.t(substr($project->durationunit,0,1)).'</td></tr></table>';
    $row[] = array('data' => $tmp, 'class' => 'stormproject-extension-duration-row');
    
    $row[] = array(
      //'data' => storm_icon_edit_node($project, $_GET) .'&nbsp;'. storm_icon_delete_node($project, $_GET),
      'data' => storm_icon_edit_node($project, $_GET), 
      'class' => 'storm_list_operations',
    );
    
    // QUICK TIMETRACKING
    if (module_exists('storm_dashboard')) {
      $row[] = array('data' => _storm_dashboard_timetracking_trigger(TRUE, $project->nid));
    }
    $rows[] = $row;
    
  }
  $o  = theme('table', $header, $rows);
  return $o;
}


/**
 * theme project page view add ons
 *
 * @param unknown_type $total_duration
 * @param unknown_type $latest_end_date
 * @return unknown_type
 */
function theme_stormproject_extension_page_view_adds($node) {
  $return = array();
  $content = '';
  
  $balance_display = variable_get('balance_display', stormproject_extension_get_balance_display_options('balance_options_default'));
  
  drupal_add_css(drupal_get_path('module', 'stormproject_extension') .'/stormproject_extension.css');

  // --------
  // AUTHOR
  // --------
  $content .= '<div class="stormfields">';
  if (!empty($node->author_nid)) {
    $content .= theme('storm_view_item', t('Author'), '<span class="stormticket-author">'. l($node->author_name, 'node/'. $node->author_nid) .'</span>');
  }
  else {
    $content .= theme('storm_view_item', t('Author'), '<span class="stormticket-author">'. l($node->author_name, 'user/'. $node->uid) .'</span>');
  }
  $content .= '</div>';

  // STATUS MAIL SETTING
  if (stormproject_extension_send_project_balance_status_message_mail()) {
    $value = t('no');
    if (!empty($node->project_status_mail)) {
      $value = t('yes');
    }
    $content .= '<div class="stormfields stormfield-project-status-mail">';
    $content .= theme('storm_view_item', t('Send nightly status mail'),  $value);
    $content .= '</div>';
  }

  $return['author'] = array(
    '#value' => $content,
    '#weight' => module_exists('content') ? content_extra_field_weight($node->type, 'stormproject_extension_add_ons_author') : -10,
  );

  $content = '';

  // -------------------
  // TIMES & DURATIONS
  // -------------------

  $class = 'balance-ok';

  $content .= '<div id="stormproject-extension-page-view-adds-durations">';

  // DATE BEGIN
  if ($balance_display['stormproject_extension_balance_display_startdate']) {
    if (!empty($node->datebegin)) {
      $content .= '<div class="stormfields stormfield-date-begin">';
      $content .= theme('storm_view_item', t('Date begin'), storm_contrib_common_time_to_date($node->datebegin, storm_contrib_common_get_custom_display_date_format()) );
      $content .= '</div>';
    }
  }

  // DATE END
  if ($balance_display['stormproject_extension_balance_display_enddate']) {
    if (!empty($node->dateend)) {
      $content .= '<div class="stormfields stormfield-date-end">';
      $content .= theme('storm_view_item', t('Date end'), storm_contrib_common_time_to_date($node->dateend, storm_contrib_common_get_custom_display_date_format()) );
      $content .= '</div>';
    }
  }

  // DEADLINE
  if ($balance_display['stormproject_extension_balance_display_project_deadline']) {
    if (!empty($node->project_deadline_time)) {
      $content .= '<div class="stormfields stormfield-deadline">';
      $content .= theme('storm_view_item', t('Deadline'), storm_contrib_common_time_to_date($node->project_deadline_time, storm_contrib_common_get_custom_display_date_format()) );
      $content .= '</div>';
    }
  }

  // LATEST ASSIGNED END DATE
  if ($balance_display['stormproject_extension_balance_display_project_deadline_time']) {
    if (!empty($node->latest_end_date['end_date'])) {
      if (!empty($node->project_deadline_time) && $node->latest_end_date['end_date'] > $node->project_deadline_time) {
        $class = 'balance-error';
      }
      $content .= '<div class="stormfields stormfield-latest-assigned-end-date">';
      $content .= theme('storm_view_item', t('Latest assigned end date'), '<span class="'. $class .'">'. storm_contrib_common_time_to_date($node->latest_end_date['end_date'], storm_contrib_common_get_custom_display_date_format()) .' '. l(t('to task/ticket'), 'node/'. $node->latest_end_date['nid']) .'</span>');
      $content .= '</div>';
      $class = 'balance-ok';
    }
  }

  // ENTERED DURATION
  if ($balance_display['stormproject_extension_balance_display_entered_duration']) {
    $content .= '<div class="stormfields stormfield-entered-duration">';
    $content .= theme('storm_view_item', t('Entered duration'), format_plural(theme('storm_contrib_common_number_format', $node->duration), '@count @unit', '@count @units', array('@unit' => $node->durationunit)) );
    $content .= '</div>';
  }
  
  // BUDGET DURATION
  if ($balance_display['stormproject_extension_balance_display_budget_duration']) {
    if (!empty($node->budget_duration)) {
      $content .= '<div class="stormfields stormfield-budget-duration">';
      $content .= theme('storm_view_item', t('Duration budget'), format_plural(theme('storm_contrib_common_number_format', $node->budget_duration), '@count @unit', '@count @units', array('@unit' => $node->budget_duration_unit)) );
      $content .= '</div>';
    }
  }

  // STILL OPEN DURATION CALCULATED BY SYSTEM
  if ($balance_display['stormproject_extension_balance_display_still_open_durations']) {
    if (!empty($node->total_open_duration)) {
      if (!empty($node->duration) && $node->total_open_duration > $node->duration ) {
        $class = 'balance-error';
      }
      $content .= '<div class="stormfields">';
      $content .= theme('storm_view_item', t('Still open durations'), '<span class="'. $class .'">'. format_plural(theme('storm_contrib_common_number_format', $node->total_open_duration), '@count @unit', '@count @units', array('@unit' => $node->budget_duration_unit)) .'</span> <span class="last-update">('. t('real time calculation') .')</span>');
      $content .= '</div>';
      $class = 'balance-ok';
    }
  }

  // REAL DURATION TILL NOW
  if ($balance_display['stormproject_extension_balance_display_time_taken']) {
    if (!empty($node->total_real_duration)) {
      $class = 'balance-ok';
      if ($node->total_real_duration > $node->budget_duration && !empty($node->budget_duration)) {
        $class = 'balance-error';
      }
      $content .= '<div class="stormfields stormfield-time-taken">';
      $content .= theme('storm_view_item', t('Time taken'), '<span class="'. $class .'">'. format_plural(theme('storm_contrib_common_number_format', $node->total_real_duration), '@count @unit', '@count @units', array('@unit' => $node->budget_duration_unit)) .'</span> <span class="last-update">('. storm_contrib_common_time_to_date($node->total_real_costs_last_updated, storm_contrib_common_get_custom_display_date_format() .' H:i:s' ) .')</span>');
      $content .= '</div>';
      $class = 'balance-ok';
    }
  }

  // REMAINING DURATION BUDGET 
  if ($balance_display['stormproject_extension_balance_display_remaining_budget_duration']) {
    if (!empty($node->remaining_budget_duration)) {
      if ($node->remaining_budget_duration < 0) {
        $class = 'balance-error';
      }
      $content .= '<div class="stormfields stormfield-remaining-budget-duration">';
      $content .= theme('storm_view_item', t('Remaining duration budget'), '<span class="'. $class .'">'.format_plural(theme('storm_contrib_common_number_format', $node->remaining_budget_duration), '@count @unit', '@count @units', array('@unit' => $node->budget_duration_unit)).'</span>' );
      $content .= '</div>';
    }
  }
  
  $content .= '</div>';

  $return['timing'] = array(
    '#value' => $content,
    '#weight' => module_exists('content') ? content_extra_field_weight($node->type, 'stormproject_extension_add_ons_timing') : -9.8,
  );
  $content = '';


  // -------
  // COSTS
  // -------
  // IF USER IS ALLOWED TO SEE DURATIONS AND COSTS
  // (VALUES ARE EMPTY IF USER HAS NOT THE PERMISSION)
  if ($node->access_costs) {

    $content .= '<div id="stormproject-extension-page-view-adds-costs">';

    $empty = true;
    // BUDGET COSTS
    if ($balance_display['stormproject_extension_balance_display_financial_budget']) {
      if (!empty($node->budget_costs)) {
        $content .= '<div class="stormfields stormfield-financial-budget">';
        $content .= theme('storm_view_item', t('Financial budget'), theme('storm_contrib_common_number_format', $node->budget_costs) .' '. $node->budget_costs_currency );
        $content .= '</div>';
        $empty = false;
      }
    }
    
    // PRICE
    if ($balance_display['stormproject_extension_balance_display_price']) {
      if (!empty($node->price)) {
        $content .= '<div class="stormfields stormfield-price">';
        $content .= theme('storm_view_item', t('Price'), theme('storm_contrib_common_number_format', $node->price) .' '. $node->currency );
        $content .= '</div>';
        $empty = false;
      }
    }

    // INVOICES TILL NOW
    if ($balance_display['stormproject_extension_balance_display_invoices_total']) {
        if (!empty($node->storminvoices_total)) {
          $content .= '<div class="stormfields stormfield-invoices-total">';
          $content .= theme('storm_view_item', t('Invoices'), '<span class="'. $class .'">'. theme('storm_contrib_common_number_format', $node->storminvoices_total) .' '. $node->total_real_costs_currency .'</span>'); // TODO INVOICES HAVE NO CURRENCY YET
          $content .= '</div>';
          $empty = false;
        }
    }

    // TOTAL REAL COSTS TILL NOW
    if ($balance_display['stormproject_extension_balance_display_total_costs_real']) {
      if (!empty($node->total_real_costs)) {
        $class = 'balance-ok';
        if ($node->total_real_costs > $node->budget_costs && !empty($node->budget_costs)) {
          $class = 'balance-error';
        }
        $content .= '<div class="stormfields stormfield-total-costs-real">';
        $content .= theme('storm_view_item', t('Total real costs'), '<span class="'. $class .'">'. theme('storm_contrib_common_number_format', $node->total_real_costs) .' '. $node->total_real_costs_currency .'</span>');
        $content .= '</div>';
        $empty = false;
      }
    }

    // PLANED PROFIT
    if ($balance_display['stormproject_extension_balance_display_planned_profit']) {
      if (!empty($node->planned_profit)) {
        $content .= '<div class="stormfields stormfield-planned-profit">';
        $content .= theme('storm_view_item', t('Planned profit'), theme('storm_contrib_common_number_format', $node->planned_profit) .' '. $node->planned_profit_currency );
        $content .= '</div>';
        $empty = false;
      }
    }
        
    // PLANED PROFIT RELATION
    if ($balance_display['stormproject_extension_balance_display_planned_profit_relation']) {
      if (!empty($node->planned_profit_relation)) {
        $content .= '<div class="stormfields stormfield-planned-profit-relation">';
        $content .= theme('storm_view_item', t('Planned profit relation'), theme('storm_contrib_common_number_format', $node->planned_profit_relation) .'%');
        $content .= '</div>';
        $empty = false;
      }
    }
    
    // PROFIT TILL NOW
    if ($balance_display['stormproject_extension_balance_display_profit']) {
    	if (!empty($node->profit)) {
        $class = 'balance-ok';
        if ($node->profit < 0 && !empty($node->profit)) {
          $class = 'balance-error';
        }
        $content .= '<div class="stormfields stormfield-profit">';
        $content .= theme('storm_view_item', t('Profit'), '<span class="'. $class .'">'. theme('storm_contrib_common_number_format', $node->profit) .' '. $node->profit_currency .'</span>');
        $content .= '</div>';
        $empty = false;
      }
    }

    $content .= '</div>';

    if (!$empty) {
      $return['costs'] = array(
        '#value' => $content,
        '#weight' => module_exists('content') ? content_extra_field_weight($node->type, 'stormproject_extension_add_ons_costs') : -9.6,
      );
    }

  }

  return $return;
}


/**
 * timetracking button
 *
 * @param unknown_type $node
 * @return unknown_type
 */
function theme_stormproject_extension_ticket_page_view_timetracking_trigger($node) {

  $content = '';

  // QUICK TIMETRACKING
  if (module_exists('storm_dashboard')) {
    $content .= _storm_dashboard_timetracking_trigger(TRUE, $node->nid) .' '. t('Click on clock to start timetracking');
  }
  return $content;
}



/**
 * theme project page view add ons
 *
 * @param unknown_type $total_duration
 * @param unknown_type $latest_end_date
 * @return unknown_type
 */
function theme_stormproject_extension_page_view_adds_details($node) {

  $balance_display_details = variable_get('balance_display_details', stormproject_extension_get_balance_display_options('balance_options_default'));
  
  $content = '';

  drupal_add_css(drupal_get_path('module', 'stormproject_extension') .'/stormproject_extension.css');

  // -------------------
  // TIMES & DURATIONS
  // -------------------

  $content .= '<div id="stormproject-extension-page-view-adds-durations">';

  $class = 'balance-ok';

  
  // DATE BEGIN
  if ($balance_display_details['stormproject_extension_balance_display_startdate']) {
    $content .= '<div class="stormfields stormfield-date-begin">';
    $content .= theme('storm_view_item', t('Date begin'), '<span class="'. $class .'">'. storm_contrib_common_time_to_date($node->datebegin, storm_contrib_common_get_custom_display_date_format()) .'</span>');
    $content .= '</div>';
  }
  
  // DATE END
  if ($balance_display_details['stormproject_extension_balance_display_enddate']) {
    $content .= '<div class="stormfields stormfield-date-end">';
    $content .= theme('storm_view_item', t('Date end'), '<span class="'. $class .'">'. storm_contrib_common_time_to_date($node->dateend, storm_contrib_common_get_custom_display_date_format()) .'</span>');
    $content .= '</div>';
  }

  // DEADLINE
  if ($balance_display_details['stormproject_extension_balance_display_project_deadline']) {
    if (!empty($node->project_deadline_time)) {
      $content .= '<div class="stormfields stormfield-deadline">';
      $content .= theme('storm_view_item', t('Deadline'), '<span class="'. $class .'">'. storm_contrib_common_time_to_date($node->project_deadline_time, storm_contrib_common_get_custom_display_date_format()) .'</span>');
      $content .= '</div>';
    }
  }

  // LATEST ASSIGNED END DATE
  if ($balance_display_details['stormproject_extension_balance_display_project_deadline_time']) {
    if (!empty($node->latest_end_date['end_date'])) {
      if ($node->latest_end_date['end_date'] > $node->project_deadline_time && !empty($node->project_deadline_time)) {
        $class = 'balance-error';
      }
      $content .= '<div class="stormfields stormfield-latest-assigned-end-date">';
      $content .= theme('storm_view_item', t('Latest assigned end date'), '<span class="'. $class .'">'. storm_contrib_common_time_to_date($node->latest_end_date['end_date'], storm_contrib_common_get_custom_display_date_format()) .' '. l(t('to task/ticket'), 'node/'. $node->latest_end_date['nid']) .'</span>');
      $content .= '</div>';
      $class = 'balance-ok';
    }
  }

  // BUDGET DURATION
  if ($balance_display_details['stormproject_extension_balance_display_budget_duration']) {
    if (!empty($node->budget_duration)) {
      $content .= '<div class="stormfields stormfield-budget-duration">';
      $content .= theme('storm_view_item', t('Duration budget'), '<span class="'. $class .'">'. format_plural(theme('storm_contrib_common_number_format', $node->budget_duration), '@count @unit', '@count @units', array('@unit' => $node->budget_duration_unit)) .'</span>');
      $content .= '</div>';
    }
  }

  // ESTIMATED DURATION
  if ($balance_display_details['stormproject_extension_balance_display_estimated_duration']) {
    if (!empty($node->estimated_duration)) {
  
      if (!empty($node->budget_duration) && $node->estimated_duration > $node->budget_duration) {
        $class = 'balance-error';
      }
  
      $latest_update = '';
      if (!empty($node->estimated_costs_last_updated)) {
        $latest_update = '<span class="last-update">('. storm_contrib_common_time_to_date($node->estimated_costs_last_updated, storm_contrib_common_get_custom_display_date_format() .' H:i:s' ) .')</span>';
      }
  
      $content .= '<div class="stormfields stormfield-estimated-duration">';
      $content .= theme('storm_view_item', t('Estimated duration'), '<span class="'. $class .'">'. format_plural(theme('storm_contrib_common_number_format', $node->estimated_duration), '@count @unit', '@count @units', array('@unit' => $node->budget_duration_unit)) .'</span>'. $latest_update);
      $content .= '</div>';
    }
  }

  $class = 'balance-ok';

  // STILL OPEN DURATIONS
  if ($balance_display_details['stormproject_extension_balance_display_still_open_durations']) {
    if (!empty($node->total_open_duration)) {
      if (!empty($node->budget_duration) && $node->total_open_duration > $node->budget_duration) {
        $class = 'balance-error';
      }
      $content .= '<div class="stormfields stormfield-still-open-durations">';
      $content .= theme('storm_view_item', t('Still open durations'), '<span class="'. $class .'">'. format_plural(theme('storm_contrib_common_number_format', $node->total_open_duration), '@count @unit', '@count @units', array('@unit' => $node->budget_duration_unit)) .'</span> <span class="last-update">('. t('real time calculation') .')</span>');
      $content .= '</div>';
    }
  }
  $class = 'balance-ok';

  // REAL DURATION TILL NOW
  if ($balance_display_details['stormproject_extension_balance_display_time_taken']) {
    if (!empty($node->total_real_duration)) {
      if (!empty($node->budget_duration) && $node->total_real_duration > $node->budget_duration) {
        $class = 'balance-error';
      }
      $content .= '<div class="stormfields stormfield-time-taken">';
      $content .= theme('storm_view_item', t('Time taken'), '<span class="'. $class .'">'. format_plural(theme('storm_contrib_common_number_format', $node->total_real_duration), '@count @unit', '@count @units', array('@unit' => $node->budget_duration_unit)) .'</span> <span class="last-update">('. storm_contrib_common_time_to_date($node->total_real_costs_last_updated, storm_contrib_common_get_custom_display_date_format() .' H:i:s' ) .')</span>');
      $content .= '</div>';
    }
  }
  $class = 'balance-ok';

  // REAL BILLABLE DURATION TILL NOW
  if ($balance_display_details['stormproject_extension_balance_display_billable_time_taken']) {
    if (!empty($node->total_real_billing_duration)) {
      if (!empty($node->total_real_billing_duration) && !empty($node->budget_duration) && $node->total_real_billing_duration > $node->budget_duration) {
        $class = 'balance-error';
      }
      $content .= '<div class="stormfields stormfield-billable-time-taken">';
      $content .= theme('storm_view_item', t('Billable time taken'), '<span class="'. $class .'">'. format_plural(theme('storm_contrib_common_number_format', $node->total_real_billing_duration), '@count @unit', '@count @units', array('@unit' => $node->budget_duration_unit)) .'</span> <span class="last-update">('. storm_contrib_common_time_to_date($node->total_real_costs_last_updated, storm_contrib_common_get_custom_display_date_format() .' H:i:s' ) .')</span>');
      $content .= '</div>';
    }
  }

  $class = 'balance-ok';

  // STILL OPEN DURATION + REAL BILLABLE DURATION TILL NOW
  if ($balance_display_details['stormproject_extension_balance_display_open_and_billable_time_taken']) {
    if (!empty($node->still_open_total_billable_real_duration)) {
      if ($node->still_open_total_billable_real_duration > $node->budget_duration && !empty($node->budget_duration)) {
        $class = 'balance-error';
      }
      $content .= '<div class="stormfields stormfield-open-duration-billable-time-taken">';
      $content .= theme('storm_view_item', t('Open durations + billable time taken'), '<span class="'. $class .'">'. format_plural(theme('storm_contrib_common_number_format', $node->still_open_total_billable_real_duration), '@count @unit', '@count @units', array('@unit' => $node->budget_duration_unit)) .'</span> <span class="last-update">('. storm_contrib_common_time_to_date($node->total_real_costs_last_updated, storm_contrib_common_get_custom_display_date_format() .' H:i:s' ) .')</span>');
      $content .= '</div>';
      $class = 'balance-ok';
    }
  }

  // STILL OPEN DURATION + REAL DURATION TILL NOW
  if ($balance_display_details['stormproject_extension_balance_display_open_and_time_taken']) {
    if (!empty($node->still_open_total_real_duration)) {
      if ($node->still_open_total_real_duration > $node->budget_duration && !empty($node->budget_duration)) {
        $class = 'balance-error';
      }
      $content .= '<div class="stormfields stormfield-open-duration-time-taken">';
      $content .= theme('storm_view_item', t('Open durations + time taken'), '<span class="'. $class .'">'. format_plural(theme('storm_contrib_common_number_format', $node->still_open_total_real_duration), '@count @unit', '@count @units', array('@unit' => $node->budget_duration_unit)) .'</span> <span class="last-update">('. storm_contrib_common_time_to_date($node->total_real_costs_last_updated, storm_contrib_common_get_custom_display_date_format() .' H:i:s' ) .')</span>');
      $content .= '</div>';
      $class = 'balance-ok';
    }
  }
  $content .= '</div>';


  // -------
  // COSTS
  // -------

  $content .= '<div id="stormproject-extension-page-view-adds-costs">';

  // BUDGET COSTS
  if ($balance_display_details['stormproject_extension_balance_display_financial_budget']) {
    if (!empty($node->budget_costs)) {
      $content .= '<div class="stormfields stormfield-financial-budget">';
      $content .= theme('storm_view_item', t('Financial budget'), '<span class="'. $class .'">'. theme('storm_contrib_common_number_format', $node->budget_costs) .' '. $node->budget_costs_currency .'</span>');
      $content .= '</div>';
    }
  }
  // INVOICES TILL NOW
  if ($balance_display_details['stormproject_extension_balance_display_invoices_total']) {
    if (!empty($node->storminvoices_total)) {
      $content .= '<div class="stormfields stormfield-invoices-total">';
      $content .= theme('storm_view_item', t('Invoices'), '<span class="'. $class .'">'. theme('storm_contrib_common_number_format', $node->storminvoices_total) .' '. $node->total_real_costs_currency .'</span> <span class="last-update">('. t('real time calculation') .')</span>' ); // TODO INVOICES DO NOT HAVE A CURRENCY YET
      $content .= '</div>';
    }
  }

  // ESTIMATED TIMETRACKING COSTS
  if ($balance_display_details['stormproject_extension_balance_display_timetracking_costs_estimated']) {
    if (!empty($node->estimated_timetracking_costs)) {
      if ($node->estimated_timetracking_costs > $node->budget_costs && !empty($node->budget_costs)) {
        $class = 'balance-error';
      }
      $content .= '<div class="stormfields stormfield-timetracking-costs-estimated">';
      $content .= theme('storm_view_item', t('Estimated timetracking costs'), '<span class="'. $class .'">'. theme('storm_contrib_common_number_format', $node->estimated_timetracking_costs) .' '. $node->estimated_timetracking_costs_currency .'</span> <span class="last-update">('. storm_contrib_common_time_to_date($node->estimated_costs_last_updated, storm_contrib_common_get_custom_display_date_format() .' H:i:s' ) .')</span>');
      $content .= '</div>';
      $class = 'balance-ok';
    }
  }
  // REAL TIMETRACKING COSTS TILL NOW
  if ($balance_display_details['stormproject_extension_balance_display_timetracking_costs_taken']) {
    if (!empty($node->total_real_timetracking_costs)) {
      if ($node->total_real_timetracking_costs > $node->budget_costs && !empty($node->budget_costs)) {
        $class = 'balance-error';
      }
      $content .= '<div class="stormfields stormfield-timetracking-costs-taken">';
      $content .= theme('storm_view_item', t('Timetracking costs taken'), '<span class="'. $class .'">'. theme('storm_contrib_common_number_format', $node->total_real_timetracking_costs) .' '. $node->total_real_timetracking_costs_currency .'</span> <span class="last-update">('. storm_contrib_common_time_to_date($node->total_real_costs_last_updated, storm_contrib_common_get_custom_display_date_format() .' H:i:s' ) .')</span>');
      $content .= '</div>';
      $class = 'balance-ok';
    }
  }


  // TOTAL EXPENSES COSTS
  if ($balance_display_details['stormproject_extension_balance_display_total_costs']) {
    if (!empty($node->stormexpenses_total_costs)) {
      if ($node->stormexpenses_total_costs > $node->budget_costs && !empty($node->budget_costs)) {
        $class = 'balance-error';
      }
      $content .= '<div class="stormfields stormfield-total-costs">';
      $content .= theme('storm_view_item', t('Total expenses costs'), '<span class="'. $class .'">'. theme('storm_contrib_common_number_format', $node->stormexpenses_total_costs) .'</span> <span class="last-update">('. t('real time calculation') .')</span>' ); // TODO EXPENSES DO NOT HAVE A CURRENCY YET
      $content .= '</div>';
      $class = 'balance-ok';
    }
  }

  // TOTAL ESTIMATED COSTS
  if ($balance_display_details['stormproject_extension_balance_display_total_costs_estimated']) {
    if (!empty($node->estimated_costs)) {
      if ($node->estimated_costs > $node->budget_costs && !empty($node->budget_costs)) {
        $class = 'balance-error';
      }
      $content .= '<div class="stormfields stormfield-total-costs-estimated">';
      $content .= theme('storm_view_item', t('Total estimated costs'), '<span class="'. $class .'">'. theme('storm_contrib_common_number_format', $node->estimated_costs) .' '. $node->estimated_costs_currency .'</span> <span class="last-update">('. storm_contrib_common_time_to_date($node->estimated_costs_last_updated, storm_contrib_common_get_custom_display_date_format() .' H:i:s' ) .')</span>');
      $content .= '</div>';
      $class = 'balance-ok';
    }
  }

  // TOTAL REAL COSTS TILL NOW
  if ($balance_display_details['stormproject_extension_balance_display_total_costs_real']) {
    if (!empty($node->total_real_costs)) {
      if ($node->total_real_costs > $node->budget_costs && !empty($node->budget_costs)) {
        $class = 'balance-error';
      }
      $content .= '<div class="stormfields stormfield-total-costs-real">';
      $content .= theme('storm_view_item', t('Total real costs'), '<span class="'. $class .'">'. theme('storm_contrib_common_number_format', $node->total_real_costs) .' '. $node->total_real_costs_currency .'</span> <span class="last-update">('. storm_contrib_common_time_to_date($node->total_real_costs_last_updated, storm_contrib_common_get_custom_display_date_format() .' H:i:s' ) .')</span>' );
      $content .= '</div>';
      $class = 'balance-ok';
    }
  }
  // PROFIT TILL NOW
  if ($balance_display_details['stormproject_extension_balance_display_profit']) {
    if (!empty($node->profit)) {
      $class = 'balance-ok';
      if ($node->profit < 0) {
        $class = 'balance-error';
      }
      $content .= '<div class="stormfields stormfield-profit">';
      $content .= theme('storm_view_item', t('Profit'), '<span class="'. $class .'">'. theme('storm_contrib_common_number_format', $node->profit) .' '. $node->profit_currency .'</span>');
      $content .= '</div>';
    }
  }

  $content .= '</div>';



  return $content;
}

/**
 * theme the balance status of a project
 *
 * @param unknown_type $node
 * @param unknown_type $balance
 * @return unknown_type
 */
function theme_stormproject_extension_project_balance($node) {

  $balance_display = variable_get('balance_display', stormproject_extension_get_balance_display_options('balance_options_default'));
  
  drupal_add_css(drupal_get_path('module', 'stormproject_extension') .'/stormproject_extension.css');

  $content = '';

  if (!empty($node)) {

    $balance = $node->balance;

    // -----------------------
    // DISPLAY COSTS BALANCE
    // -----------------------

    if (!empty($balance)) {

      $class = '';

      $content .= '<div id="stormproject-extension-display-balances">';

      $content .= '<div id="stormproject_extension-display-balances-title">';
      $content .= '<h2>'. t('Balances') .'</h2>';
      $content .= '</div>';

      // LATEST ASSIGNED END DATE AFTER END DATE OF PROJECT
      if (!empty($node->latest_end_date['end_date']) && !empty($node->dateend)) {
        if ($node->latest_end_date['end_date'] > $node->dateend) {
          $content .= '<div class="stormfields">';
          $content .= theme('storm_view_item', t('End date'), '<span class="balance-error">'. t('Latest assigned end date is after the project end date!') .'</span>' );
          $content .= '</div>';
        }
      }


      foreach ($balance as $balance_type => $balance_array) {

        if ('errors' == $balance_type) {
          continue;
        }

        $content .= "<br />\n";
        $content .= '<div id="stormproject_extension-display-balances-'. $balance_type .'">';
        $content .= '<h3>'. ucfirst($balance_type) .'</h3>';

        if (!empty($balance_array)) {
          foreach ($balance_array as $ratio_type => $type_array) {

            $relation_text = '';

            if ($balance_display['stormproject_extension_balance_display_'.$ratio_type]) {
              $display_balance = TRUE;
            } else {
              $display_balance = FALSE;
            }
            
            // BUILD RELATIONSHIP TEXT
            switch ($ratio_type) {

              // ---------
              // COSTS
              // ---------

              // REAL TIMETRACKING COSTS - ESTIMATED COSTS RELATIONSHIP
              case 'real-estimate-costs-ratio':
                $relation_text = t('Real- estimated costs relation');
//                $relation_text = t('Real-estimated');
                break;

              // REAL TIMETRACKINGS - BUDGET RELATIONSHIP
              case 'real-budget-costs-ratio':
                $relation_text = t('Real - budget costs relation');
//                $relation_text = t('Real-budget costs');
                break;

              // ESTIMATED COSTS - BUDGET COSTS RELATIONSHIP
              case 'estimate-budget-costs-ratio':
                $relation_text = t('Estimated - budget costs relation');
//                $relation_text = t('Estimated-budget costs');
                break;


              // ----------
              // INVOICES
              // ----------

              // PROFIT CONTRIBUTION
              case 'profit-contribution':
                $relation_text = t('Profit Contribution');
                break;

              // COMPARE INVOICES - REAL COSTS
              case 'invoices-real-costs-ratio':
                $relation_text = t('Invoices - real costs relation');
                break;

              // COMPARE INVOICES - ESTIMATED COSTS
              case 'invoices-estimate-costs-ratio':
                $relation_text = t('Invoices - estimated costs relation');
                break;

              // COMPARE INVOICES - BUDGET COSTS
              case 'invoices-budget-costs-ratio':
                $relation_text = t('Invoices - budget costs relation');
                break;



              // ----------
              // DURATION
              // ----------

              // REAL TIMETRACKINGS DURATION - ESTIMATED DURATION RELATIONSHIP
              case 'real-estimate-duration-ratio':
                $relation_text = t('Real - estimated duration relation');
//                $relation_text = t('Real-estimated duration');
                break;

              // REAL TIMETRACKINGS DURATION - BUDGET DURATON RELATIONSHIP
              case 'real-budget-duration-ratio':
                $relation_text = t('Real - budget duration relation');
//                $relation_text = t('Real-budget duration');
                break;

              // ESTIMATED DURATION - BUDGET DURATION RELATIONSHIP
              case 'estimate-budget-duration-ratio':
                $relation_text = t('Estimated - budget duration relation');
//                $relation_text = t('Estimated-budget duration');
                break;

              // STILL OPEN DURATIONS + REAL TIMETRACKINGS DURATION - BUDGET RELATIONSHIP
              case 'open+real-budget-duration-ratio':
                $relation_text = t('Open + real - budget duration relation');
//                $relation_text = t('Open+real-budget duration');
                break;

            }


            // BUILD CSS CLASS
            switch ($type_array['status']) {

              case 'ok':
                $class = 'balance-ok';
                break;

              case 'warning':
                $class = 'balance-warning';
                break;

              case 'overdrawn':
                $class = 'balance-error';
                break;

            }

            if (!empty($type_array['percentage']) && $display_balance) {
              $content .= '<div class="stormfields stormfield-'.$ratio_type.'">';
              $content .= theme('storm_view_item', $relation_text, '<span class="'. $class .'">'. theme('storm_contrib_common_number_format', $type_array['percentage']) .'%</span>' );
              $content .= '</div>';
            }

          }
        }

        $content .= '</div>'; // END <div id="stormproject_extension-display-balances-'. $balance_type .'">

      }

      // PROFIT CONTRIBUTION TILL NOW
      if (!empty($node->profit_contribution)) {
        $class = 'balance-ok';
        if ($node->profit_contribution < 0 && !empty($node->profit_contribution)) {
          $class = 'balance-error';
        }
        $content .= '<div class="stormfields stormfield-profit-contribution">';
        $content .= theme('storm_view_item', t('Profit contribution'), '<span class="'. $class .'">'. theme('storm_contrib_common_number_format', $node->profit_contribution) .' % </span>');
        $content .= '</div>';
      }

      $content .= '<div id="stormproject_extension-display-balances-details-link">';
      $content .=  l(t('see details'), 'node/'. $node->nid .'/balance');
      $content .= '</div>';

      $content .= '</div>'; // END <div id="stormproject_extension-display-balances">

    }

  }
  return $content;
}




/**
 * theme the balance status of a project
 *
 * @param unknown_type $node
 * @param unknown_type $balance
 * @return unknown_type
 */
function theme_stormproject_extension_project_balance_details($node) {
  
  $balance_display_details = variable_get('balance_display_details', stormproject_extension_get_balance_display_options('balance_options_default'));
  
  drupal_add_css(drupal_get_path('module', 'stormproject_extension') .'/stormproject_extension.css');

  $content = '';
  
  if (!empty($node)) {

    $balance = $node->balance;

    // -----------------------
    // DISPLAY COSTS BALANCE
    // -----------------------

    if (!empty($balance)) {

      $class = '';

      $content .= '<div id="stormproject-extension-display-balances-details">';

      $content .= '<div id="stormproject_extension-display-balances-title">';
      $content .= '<h2>'. t('Balances') .'</h2>';
      $content .= '</div>';

      if (!empty($node->latest_end_date['end_date']) && !empty($node->dateend)) {
        if ($node->latest_end_date['end_date'] > $node->dateend) {
          $content .= '<div class="stormfields">';
          $content .= theme('storm_view_item', t('End date'), '<span class="balance-error">'. t('Latest assigned end date is after the project end date!') .'</span>' );
          $content .= '</div>';
        }
      }

      foreach ($balance as $balance_type => $balance_array) {

        if ('errors' == $balance_type) {
          continue;
        }

        $content .= "<br />\n";
        $content .= '<div id="stormproject_extension-display-balances-'. $balance_type .'">';
        $content .= '<h3>'. ucfirst($balance_type) .'</h3>';

        if (!empty($balance_array)) {
          foreach ($balance_array as $ratio_type => $type_array) {

            if ($balance_display_details['stormproject_extension_balance_display_'.$ratio_type]) {
              $display_balance = TRUE;
            } else {
              $display_balance = FALSE;
            }
            
            // BUILD RELATIONSHIP TEXT
            switch ($ratio_type) {

              // ---------
              // COSTS
              // ---------

              // PROFIT CONTRIBUTION
              case 'profit-contribution':
                $relation_text = t('Profit Contribution');
                break;

              // REAL TIMETRACKING COSTS - ESTIMATED COSTS RELATIONSHIP
              case 'real-estimate-costs-ratio':
                
                $relation_text = t('Real- estimated costs relation');
//                $relation_text = t('Real-estimated');
                break;

              // REAL TIMETRACKINGS - BUDGET RELATIONSHIP
              case 'real-budget-costs-ratio':
                $relation_text = t('Real - budget costs relation');
//                $relation_text = t('Real-budget costs');
                break;

              // ESTIMATED COSTS - BUDGET COSTS RELATIONSHIP
              case 'estimate-budget-costs-ratio':
                $relation_text = t('Estimated - budget costs relation');
//                $relation_text = t('Estimated-budget costs');
                break;


              // ---------
              // INVOICES
              // ---------

                // ----------
              // INVOICES
              // ----------

              // PROFIT CONTRIBUTION
              case 'profit-contribution':
                $relation_text = t('Profit Contribution');
                break;

              // COMPARE INVOICES - REAL COSTS
              case 'invoices-real-costs-ratio':
                $relation_text = t('Invoices - real costs relation');
                break;

              // COMPARE INVOICES - ESTIMATED COSTS
              case 'invoices-estimate-costs-ratio':
                $relation_text = t('Invoices - estimated costs relation');
                break;

              // COMPARE INVOICES - BUDGET COSTS
              case 'invoices-budget-costs-ratio':
                $relation_text = t('Invoices - budget costs relation');
                break;


              // ----------
              // DURATION
              // ----------

              // REAL TIMETRACKINGS DURATION - ESTIMATED DURATION RELATIONSHIP
              case 'real-estimate-duration-ratio':
                $relation_text = t('Real - estimated duration relation');
//                $relation_text = t('Real-estimated duration');
                break;

              // REAL TIMETRACKINGS DURATION - BUDGET DURATON RELATIONSHIP
              case 'real-budget-duration-ratio':
                $relation_text = t('Real - budget duration relation');
//                $relation_text = t('Real-budget duration');
                break;

              // ESTIMATED DURATION - BUDGET DURATION RELATIONSHIP
              case 'estimate-budget-duration-ratio':
                $relation_text = t('Estimated - budget duration relation');
//                $relation_text = t('Estimated-budget duration');
                break;

              // STILL OPEN DURATIONS + REAL TIMETRACKINGS DURATION - BUDGET RELATIONSHIP
              case 'open+real-budget-duration-ratio':
                $relation_text = t('Open + real - budget duration relation');
//                $relation_text = t('Open+real-budget duration');
                break;

            }

            // BUILD CSS CLASS
            switch ($type_array['status']) {

              case 'ok':
                $class = 'balance-ok';
                break;

              case 'warning':
                $class = 'balance-warning';
                break;

              case 'overdrawn':
                $class = 'balance-error';
                break;

            }

            
            // TODO MAYBE DISPLAY CHARTS ?

            if (!empty($type_array['percentage']) && $display_balance) {
              $content .= '<div class="stormfields stormfield-'.$ratio_type.'">';
              $content .= theme('storm_view_item', $relation_text, '<span class="'. $class .'">'. theme('storm_contrib_common_number_format', $type_array['percentage']) .'%</span>' );
              $content .= '</div>';
            }

          }
        }

        $content .= '</div>'; // END <div id="stormproject_extension-display-balances-'. $balance_type .'">

      }

      $content .= '</div>'; // END <div id="stormproject_extension-display-balances">

    }

  }

  return $content;
}

/**
 * theme admin settings for balance display settings
 * @param unknown_type $form
 */
function theme_stormproject_extension_admin_form_balance_display_settings_table($form) {
  $output = "";

  $header = array(t('Display'), $form['balance_display']['#title'], $form['balance_display_details']['#title']);

  unset($form['balance_display']['#title']);
  unset($form['balance_display_details']['#title']);

  $rows = array();
  foreach(element_children($form['balance_display']) as $key) {
    
    $row = array();

    if (empty($form['balance_display_details'][$key]['#title'])) {
      $row[] = $form['balance_display'][$key]['#title'];
    } else {
      $row[] = $form['balance_display_details'][$key]['#title'];
    }

    if ('' == $form['balance_display'][$key]['#title']) {
      $form['balance_display'][$key]['#type'] = 'hidden'; 
    }
    if ('' == $form['balance_display_details'][$key]['#title']) {
      $form['balance_display_details'][$key]['#type'] = 'hidden'; 
    }
    
    unset($form['balance_display'][$key]['#title']);
    $row[] = drupal_render($form['balance_display'][$key]);

    unset($form['balance_display_details'][$key]['#title']);
    
    $row[] = drupal_render($form['balance_display_details'][$key]);

    $rows[] = $row;
  }

  
  $output .= theme('table', $header, $rows);

  $output .= drupal_render($form);

  return $output;
}

