<?php

/**
 * @file stormtimetracking_extension.theme.inc
 *
 * theming functions for module stormtimetracking_extension
 */



/**
 * theme timetracking node page view
 *
 * @param unknown_type $node
 * @return unknown_type
 */
function theme_stormtimetracking_extension_display_timetracking_data($node, $node_person) {

  $content = '';

  // AUTHOR
  if (empty($node_person)) {
    $content .= '<div class="stormfields stormfield-author">';
    $content .= theme('storm_view_item', t('Author'), l($node_person->title, 'node/'. $node_person->nid));
    $content .= '</div>';
  }

  // TRACKINGDATE
  $content .= '<div class="stormfields stormfield-trackingdate">';
  $content .= theme('storm_view_item', t('Tracking date'), date(storm_contrib_common_get_custom_display_date_format(), storm_contrib_common_timestamp_to_timezone($node->trackingdate)));
  
  $content .= '</div>';

  // START TIME
  $content .= '<div class="stormfields stormfield-date-begin">';
  $content .= theme('storm_view_item', t('Begin'), $node->timebegin);
  $content .= '</div>';

  // END TIME
  $content .= '<div class="stormfields stormfield-date-end">';
  $content .= theme('storm_view_item', t('End'), $node->timeend);
  $content .= '</div>';

  $content .= '<div class="stormfields stormfield-duration">';
  $content .= theme('storm_view_item', t('Duration'), format_plural(theme('storm_contrib_common_number_format', $node->duration), '@count hour', '@count hours' ));
  $content .= '</div>';

  return $content;
}


/**
 * display progress of node
 *
 * @param unknown_type $node
 * @return unknown_type
 */
function theme_stormtimetracking_extension_display_timetracking_progress($node) {

  drupal_add_css(drupal_get_path('module', 'stormtimetracking_extension') .'/stormtimetracking_extension.css');

  $content = '';

  // IF NO DURATION IS ENTERED
  if (empty($node->progress_in_percentage) && empty($node->duration)) {
    $content .= '<div class="storm-timetracking-progress-'. $node->type .'">';
    $content .= '<h3>'. t('Progress') ."</h3>";
    $content .= t('No duration entered, so calculation of progress is not possible');
    $content .= '</div>';
    $content .= "<br />\n";
    return $content;
  }


  $content .= '<div class="storm-timetracking-progress-'. $node->type .'">';

  $content .= '<h3>'. t('Progress') ."</h3>";

  $content .= '<div class="storm-timetracking-progress-label">';
  // IF BUDGET DURATION AVAILABLE
  if ('budget_duration' == $node->progress_type) {
    $content .= t('(Ratio of budget duration - timetrackings till now + still open durations)');
  }
  // ELSE USE ENTERED DURATION
  else {
    $content .= t('(Ratio of entered duration - timetrackings till now + still open durations)');
  }

  $content .= '</div>';

  if (module_exists('charts')) {
    // PERCENTAGE
    $class = 'status';
    if (number_format($node->progress_in_percentage, 2) > 100) { // KEEP number_format() for check
      $class = 'error';
    }
    $content .= '<div class="storm-timetracking-progress-percentage '. $class .'">';
    $content .=  '<strong>'. theme('storm_contrib_common_number_format', $node->progress_in_percentage) .'% </strong>';
    $content .= '</div>';


    // -------
    // CHART
    // -------

    // PIE 3D
    if ((100 - $node->progress_in_percentage) <= 0) {
      $values = array(
        array('#value' => $node->progress_in_percentage, '#label' => theme('storm_contrib_common_number_format', $node->progress_in_percentage) .'% '. t('finished')),
      );
    }
    else {
      $values = array(
        array('#value' => $node->progress_in_percentage, '#label' => theme('storm_contrib_common_number_format', $node->progress_in_percentage) .'% '. t('finished')),
        array('#value' => (100 - $node->progress_in_percentage), '#label' => theme('storm_contrib_common_number_format', (100 - $node->progress_in_percentage)) .'% '. t('still open')),
      );
    }

    $chart = storm_contrib_common_build_chart('pie3D', $values, 360, 100);

    if (!empty($chart)) {
      $content .= '<div class="stormperson-utilisation-chart">';
      $content .= $chart;
      $content .= '</div>';
    }
  }
  else {
    $content .= '<div class="stormtimtracking-progress-bar">';
    $content .= theme('storm_contrib_common_progress_bar', $node->progress_in_percentage/100, 1, 390);;
    $content .= '</div>';
  }


  $content .= '</div>';

  return $content;
}



/**
 * thme timetrackings of person
 *
 * @param unknown_type $trackings
 * @param unknown_type $date
 * @return unknown_type
 */
function theme_stormtimetracking_extension_person_timetrackings($trackings, $date) {

  drupal_add_css(drupal_get_path('module', 'stormtimetracking_extension') .'/stormtimetracking_extension.css');

  $content = '';

  $content .= '<div class="stormtimetracking-extension-person-timetrackings-date">';
  $content .= '<strong>'. t('Timetrackings on @date', array('@date' => storm_contrib_common_time_to_date(storm_contrib_common_date_to_time($date), storm_contrib_common_get_custom_display_date_format()))) .'</strong>';
  $content .= '</div>';

  $content .= '<div class="stormtimetracking-extension-person-timetrackings-add-icon">';
  $content .= $trackings['add_icon'];
  $content .= '</div>';


  if (!empty($trackings) && is_array($trackings)) {

    $class = 'balance-ok';

    $content .= "<br />\n";

    // WEEKEND
    if ('weekend' == $trackings['weekend']) {
      $class = 'balance-error';
      $content .= '<div class="stormfields stormfield-weekend">';
      $content .= theme('storm_view_item', t('Weekend'), '<span class="'. $class .'">'. t('Weekend') .'</span>' );
      $content .= '</div>';
      $class = 'balance-ok';
    }

    // NATIONAL HOLIDAY
    if ('national_holiday' == $trackings['holiday']) {
      $class = 'balance-error';
      $content .= '<div class="stormfields stormfield-holiday">';
      $content .= theme('storm_view_item', t('Holiday'), '<span class="'. $class .'">'. t('This is a national holiday') .'</span>' );
      $content .= '</div>';
      $class = 'balance-ok';
    }

    // FULL DAY HOLIDAY
    if ('full_day_holiday' == $trackings['holiday']) {
      $class = 'balance-error';
      $content .= '<div class="stormfields stormfield-holiday">';
      $content .= theme('storm_view_item', t('Holiday'), '<span class="'. $class .'">'. t('Person has holiday on @date', array('@date' => storm_contrib_common_time_to_date(storm_contrib_common_date_to_time($date), storm_contrib_common_get_custom_display_date_format()))) .'</span>' );
      $content .= '</div>';
      $class = 'balance-ok';
    }

    // HALF DAY HOLIDAY
    if ('half_day_holiday' == $trackings['holiday']) {
      $class = 'balance-error';
      $content .= '<div class="stormfields stormfield-holiday">';
      $content .= theme('storm_view_item', t('Holiday'), '<span class="'. $class .'">'. t('Person has a half day holiday on @date', array('@date' => storm_contrib_common_time_to_date(storm_contrib_common_date_to_time($date), storm_contrib_common_get_custom_display_date_format()))) .'</span>' );
      $content .= '</div>';
      $class = 'balance-ok';
    }

    // NOT A WORKING DAY OF THE PERSON
    if ('not_a_working_day' == $trackings['not_a_working_day']) {
      $class = 'balance-error';
      $content .= '<div class="stormfields stormfield-holiday">';
      $content .= theme('storm_view_item', t('Not a working day'), '<span class="'. $class .'">'. t('The person normally does not work on @dates', array('@date' => date('l', storm_contrib_common_date_to_time($date)))) .'</span>' ); // TODO TRANSLATION OF WEEKDAY
      $content .= '</div>';
      $class = 'balance-ok';
    }


    $content .= '<div class="stormfields stormfield-total">';
    $content .= theme('storm_view_item', t('Total'), '<span class="'. $class .'">'. theme('storm_contrib_common_format_plural_duration', $trackings['balance_result']['working_hours'], 'hour') .'</span>' );
    $content .= '</div>';

    // TOTAL TRACKED DURATION
    $content .= '<div class="stormfields stormfield-tracked-duration-total">';
    $content .= theme('storm_view_item', t('Tracked duration total'), '<span class="'. $class .'">'. theme('storm_contrib_common_format_plural_duration', $trackings['duration'], 'hour') .'</span>' );
    $content .= '</div>';

    //TRACKING TIME / WORK TIME RATIO
    $ratio_limit = stormtimetracking_extension_get_timetracking_work_time_ratio();
    if ($trackings['balance_result']['percentage'] < $ratio_limit) {
      $class = 'balance-error';
    }
    $content .= '<div class="stormfields stormfield-tracked-work-ratio">';
    $content .= theme('storm_view_item', t('Tracking/work time ratio'), '<span class="'. $class .'">'. theme('storm_contrib_common_number_format', $trackings['balance_result']['percentage']) .'%</span>' );
    $content .= '</div>';

    // WORKING TIME NOT TRACKED
    $content .= '<div class="stormfields stormfield-tracked-time-left">';
    $content .= theme('storm_view_item', t('Work time left'), '<span class="'. $class .'">'. theme('storm_contrib_common_format_plural_duration', $trackings['balance_result']['time_left_in_hours'], 'hour') .'</span>' );
    $content .= '</div>';

    $class = 'balance-ok';

    // TOTAL COSTS ON TRACKING
    if (!empty($trackings['total_costs'])) {
      $content .= '<div class="stormfields stormfield-duration-costs-total">';
      $content .= theme('storm_view_item', t('Duration costs total'), '<span class="'. $class .'">'. theme('storm_contrib_common_number_format', $trackings['total_costs']) .' '. $trackings['currency'] .'</span>' );
      $content .= '</div>';
    }


    $header = array(
      array('data' => t('Time')),
      array('data' => t('Duration in hours')),
      array('data' => t('Title')),
      array('data' => t('Tracked on')),
      array('data' => t('Project')),
      array('data' => t('Operations')),
    );

    $rows = array();

    // first check for holidays to stay on top
    foreach ($trackings as $nid => $tracking_array) {

      if ('holiday_trackings' == $nid && !empty($tracking_array)) {
        $row = array();
        $row[] = array('data' => $tracking_array['title']);
        $row[] = array('data' => theme('storm_contrib_common_format_plural_duration', $tracking_array['duration'], 'hour'));

        $row[] = array('data' => $tracking_array['title']);
        $row[] = array('data' => $tracking_array['title']);
        $row[] = array('data' => $tracking_array['title']);

        // EDIT ICON
        $tmp = array('data' => '');
        $row[] = $tmp;

        $rows[] = array('data' => $row);
      }

    }

    foreach ($trackings as $nid => $tracking_array) {

      if (is_numeric($nid) && !empty($tracking_array)) {

        $tracking_array['type'] = 'stormtimetracking';

        if (!empty($tracking_array['ticket_nid'])) {
          $type = 'ticket';
        }
        elseif (!empty($tracking_array['task_nid'])) {
          $type = 'task';
        }
        elseif (!empty($tracking_array['project_nid'])) {
          $type = 'project';
        }
        else {
          $type = '';
        }

        $row = array();
        $row[] = array('data' => $tracking_array['timebegin'] .'-'. $tracking_array['timeend']);
        $row[] = array('data' => theme('storm_contrib_common_format_plural_duration', $tracking_array['duration'], 'hour'));
        $row[] = array('data' => l($tracking_array['title'], 'node/'. $tracking_array['nid']));
        if (!empty($type)) {
          $row[] = array('data' => l($tracking_array[$type .'_title'], 'node/'. $tracking_array[$type .'_nid']) .' ('. ucfirst($type) .')');
        }
        else {
          $row[] = array('data' => ' ');
        }
        $row[] = array('data' => l($tracking_array['project_title'], 'node/'. $tracking_array['project_nid']));

        // EDIT ICON
        $tmp = array('data' => '');

        if (node_access('update', (object) $tracking_array)) {
        	$params = $_GET;
        	// unset project_nid from $_GET array, because it caused overriding nodes original title 
        	unset($params['project_nid']);
          $tmp['data'] =  storm_icon_edit_node((object) $tracking_array, $params) .' ';
        }
        $row[] = $tmp;

        $rows[] = array('data' => $row);

      }

    }

    if (!empty($rows)) {
      $content .= theme('table', $header, $rows);
      if (!empty($trackings['pager'])) {
        $content .= $trackings['pager'];
      }
    }

  }
  else {
    $content .= '<div class="stormtimetracking-extension-display-type-timetrackings-no-data">';
    $content .= t('No timetrackings available');
    $content .= '</div>';
  }


  // EXPORT
  if (module_exists('storm_exports')) {

    // IF EXPORT BUTTON WAS PRESSED
    if (!empty($_SESSION['storm_exports_export_'. request_uri() ])) {
      $vars['filename'] = 'person-timetrackings';
      $vars['header'] = $header;
      $vars['rows'] = $rows;
      storm_exports_export($vars);
    }

  }

  return $content;
}


/**
 * thme timetrackings of person
 *
 * @param unknown_type $trackings
 * @param unknown_type $date
 * @return unknown_type
 */
function theme_stormtimetracking_extension_monthly_person_timetrackings($node, $result, $year, $month) {

  drupal_add_css(drupal_get_path('module', 'stormtimetracking_extension') .'/stormtimetracking_extension.css');

  $content = '';

  if (!empty($year) && !empty($month)) {
    $content .= '<div class="stormtimetracking-extension-display-type-timetrackings">';
    $content .= '<strong>'. t('Timetracking statstic for @month @year', array('@month' => $month, '@year' => $year)) .'</strong>';
    $content .= '</div>';
  }

  if (!empty($result)) {

    $class = 'balance-ok';

    $content .= "<br />\n";

    // TOTAL WORK DAYS IN MONTH
    $content .= '<div class="stormfields stormfield-total-days-month">';
    $content .= theme('storm_view_item', t('Total working days in month'), '<span class="'. $class .'">'. format_plural(theme('storm_contrib_common_number_format', $result['balance_result']['working_days_in_month'], 0), '@count day', '@count days') .'</span>' );
    $content .= '</div>';

    // TOTAL WORK HOURS IN MONTH
    $content .= '<div class="stormfields stormfield-total-hours-month">';
    $content .= theme('storm_view_item', t('Total working hours in month'), '<span class="'. $class .'">'. format_plural(theme('storm_contrib_common_number_format', $result['balance_result']['working_hours_in_month']), '@count hour', '@count hours') .'</span>' );
    $content .= '</div>';

     // PERSONS WORK DAYS IN MONTH
    $content .= '<div class="stormfields stormfield-person-days-month">';
    $content .= theme('storm_view_item', t('Persons working days in month'), '<span class="'. $class .'">'. format_plural(theme('storm_contrib_common_number_format', $result['balance_result']['persons_working_days_in_month'], 0), '@count day', '@count days') .'</span>' );
    $content .= '</div>';

    // TOTAL WORK HOURS IN MONTH
    $content .= '<div class="stormfields stormfield-person-hours-month">';
    $content .= theme('storm_view_item', t('Persons working hours in month'), '<span class="'. $class .'">'. format_plural(theme('storm_contrib_common_number_format', $result['balance_result']['persons_working_hours_in_month']), '@count hour', '@count hours') .'</span>' );
    $content .= '</div>';

    // TOTAL TRACKED DURATION
    $content .= '<div class="stormfields stormfield-tracked-duration-total">';
    $content .= theme('storm_view_item', t('Tracked duration total'), '<span class="'. $class .'">'. format_plural(theme('storm_contrib_common_number_format', $result['tracking_duration_total']), '@count hour', '@count hours') .'</span>' );
    $content .= '</div>';

    // TOTAL TRACKED BILLING DURATION
    $content .= '<div class="stormfields stormfield-tracked-duration-total-billable">';
    $content .= theme('storm_view_item', t('Tracked billable duration total'), '<span class="'. $class .'">'. format_plural(theme('storm_contrib_common_number_format', $result['tracking_billing_duration_total']), '@count hour', '@count hours') .'</span>' );
    $content .= '</div>';

    // TRACKING TIME / WORK TIME RATIO
    $ratio_limit = stormtimetracking_extension_get_timetracking_work_time_ratio();
    if ($result['balance_result']['percentage'] < $ratio_limit) {
      $class = 'balance-error';
    }
    $content .= '<div class="stormfields stormfield-tracked-work-ratio">';
    $content .= theme('storm_view_item', t('Tracking/work time ratio'), '<span class="'. $class .'">'. theme('storm_contrib_common_number_format', $result['balance_result']['percentage']) .'%</span>' );
    $content .= '</div>';

    // WORK TIME LEFT
    $content .= '<div class="stormfields stormfield-tracked-time-left">';
    $content .= theme('storm_view_item', t('Work time left'), '<span class="'. $class .'">'. format_plural(theme('storm_contrib_common_number_format', $result['balance_result']['time_left_in_hours']), '@count hour', '@count hours') .'</span>' );
    $content .= '</div>';

    $class = 'balance-ok';

    // REAL COSTS PER HOUR BY TOTAL DURATION IN DEPENDENCY OF MONTHLY SALARY
    if (!empty($result['person_internal_costs_per_hour_by_monthly_salary'])) {

       $content .= "<br />\n";

      $content .= '<div class="stormfields stormfield-real-costs-hour">';
      $item  = '<span class="'. $class .'">'. theme('storm_contrib_common_number_format', $result['person_internal_costs_per_hour_by_monthly_salary']) .' '. $result['person_internal_costs_per_hour_currency_by_monthly_salary'] .'</span>';
      $item .= ' <span class="storm-timetracking-progress-label">('. format_plural(theme('storm_contrib_common_number_format', $result['tracking_duration_total']), '@count hour', '@count hours') .' duration / '. $node->person_monthly_salary .' '. $node->person_monthly_salary_currency .' monthly salary)</span>';
      $content .= theme('storm_view_item', t('Real costs per hour by duration'), $item);
      $content .= '</div>';
    }

    // DIFFERENCE BETWEEN TOTAL COSTS AND MONTHLY SALARY
    if (!empty($result['difference_total_costs_person_monthly_salary'])) {
      $content .= '<div class="stormfields stormfield-costs-salary">';
      $item  = '<span class="'. $class .'">'.  theme('storm_contrib_common_number_format', $result['difference_total_costs_person_monthly_salary']) .' '. $result['difference_total_costs_person_monthly_salary_currency'] .'</span>';
      $item .= ' <span class="storm-timetracking-progress-label">('. theme('storm_contrib_common_number_format', $result['costs_total']) .' '. $result['costs_currency_total']  .' total costs - '. $node->person_monthly_salary .' '. $node->person_monthly_salary_currency .' monthly salary)</span>';
      $content .= theme('storm_view_item', t('Difference between total costs and monthly salary'), $item);
      $content .= '</div>';
    }

    // REAL BILLING COSTS PER HOUR BY TOTAL BILLING DURATION IN DEPENDENCY OF MONTHLY SALARY
    if (!empty($result['person_internal_billing_costs_per_hour_by_monthly_salary'])) {
      $content .= '<div class="stormfields stormfield-costs-hour-billable">';
      $item  = '<span class="'. $class .'">'.  theme('storm_contrib_common_number_format', $result['person_internal_billing_costs_per_hour_by_monthly_salary']) .' '. $result['person_internal_billing_costs_per_hour_currency_by_monthly_salary'] .'</span>';
      $item .= ' <span class="storm-timetracking-progress-label">('. format_plural(theme('storm_contrib_common_number_format', $result['tracking_billing_duration_total']), '@count hour', '@count hours') .' billable duration / '. $node->person_monthly_salary .' '. $node->person_monthly_salary_currency .' monthly salary)</span>';
      $content .= theme('storm_view_item', t('Real costs per hour by billable duration'), $item);
      $content .= '</div>';
    }

    // DIFFERENCE BETWEEN TOTAL BILLING COSTS AND MONTHLY SALARY
    if (!empty($result['difference_total_billing_costs_person_monthly_salary'])) {
      $content .= '<div class="stormfields stormfield-costs-billing-salary">';
      $item  = '<span class="'. $class .'">'.  theme('storm_contrib_common_number_format', $result['difference_total_billing_costs_person_monthly_salary']) .' '. $result['difference_total_billing_costs_person_monthly_salary_currency'] .'</span>';
      $item .= ' <span class="storm-timetracking-progress-label">('. theme('storm_contrib_common_number_format', $result['billing_costs_total']) .' '. $result['billing_costs_currency_total']  .' total billing costs - '. $node->person_monthly_salary .' '. $node->person_monthly_salary_currency .' monthly salary)</span>';
      $content .= theme('storm_view_item', t('Difference between total billing costs and monthly salary'), $item);
      $content .= '</div>';
    }


    $content .= "<br />\n";

    // LAST UPDATED
    $content .= '<div class="stormfields stormfield-last-update">';
    $content .= theme('storm_view_item', t('Last updated'), '<span class="'. $class .'">'. storm_contrib_common_time_to_date($result['total_last_updated'], storm_contrib_common_get_custom_display_date_format() .' H:i:s' ) .'</span>' );
    $content .= '</div>';


    $content .= "<br />\n";

    $content .= theme("stormtimetracking_extension_person_statistic_table", $result);

  }
  else {
    $content .= '<div class="stormtimetracking-extension-display-type-timetrackings-no-data">';
    $content .= t('No timetrackings available');
    $content .= '</div>';
  }


  // EXPORT
  if (module_exists('storm_exports')) {

    // IF EXPORT BUTTON WAS PRESSED
    if (!empty($_SESSION['storm_exports_export_'. request_uri() ])) {
      $vars['filename'] = 'person-monthly-timetracking-statistic';
      $vars['header'] = $GLOBALS['storm_exports_export_header'];
      $vars['rows'] = $GLOBALS['storm_exports_export_rows'];
      storm_exports_export($vars);
    }

  }

  return $content;
}

/**
 * thme timetrackings of person
 *
 * @param unknown_type $trackings
 * @param unknown_type $date
 * @return unknown_type
 */
function theme_stormtimetracking_extension_weekly_person_timetrackings($node, $result, $year, $week) {

  drupal_add_css(drupal_get_path('module', 'stormtimetracking_extension') .'/stormtimetracking_extension.css');

  $content = '';

  if (!empty($year) && !empty($week)) {
    $content .= '<div class="stormtimetracking-extension-display-type-timetrackings">';
    $content .= '<strong>'. t('Timetracking statstic for week @week of @year', array('@week' => $week, '@year' => $year)) .'</strong>';
    $content .= '</div>';
  }

  if (!empty($result)) {

    $class = 'balance-ok';

    $content .= "<br />\n";

    // TOTAL WORK DAYS IN MONTH
    $content .= '<div class="stormfields stormfield-total-days-month">';
    $content .= theme('storm_view_item', t('Total working days in week'), '<span class="'. $class .'">'. format_plural(theme('storm_contrib_common_number_format', $result['balance_result']['working_days_in_week'], 0), '@count day', '@count days') .'</span>' );
    $content .= '</div>';

    // TOTAL WORK HOURS IN MONTH
    $content .= '<div class="stormfields stormfield-total-hours-month">';
    $content .= theme('storm_view_item', t('Total working hours in week'), '<span class="'. $class .'">'. format_plural(theme('storm_contrib_common_number_format', $result['balance_result']['working_hours_in_week']), '@count hour', '@count hours') .'</span>' );
    $content .= '</div>';

     // PERSONS WORK DAYS IN MONTH
    $content .= '<div class="stormfields stormfield-person-days-month">';
    $content .= theme('storm_view_item', t('Persons working days in week'), '<span class="'. $class .'">'. format_plural(theme('storm_contrib_common_number_format', $result['balance_result']['persons_working_days_in_week'], 0), '@count day', '@count days') .'</span>' );
    $content .= '</div>';

    // TOTAL WORK HOURS IN MONTH
    $content .= '<div class="stormfields stormfield-person-hours-month">';
    $content .= theme('storm_view_item', t('Persons working hours in week'), '<span class="'. $class .'">'. format_plural(theme('storm_contrib_common_number_format', $result['balance_result']['persons_working_hours_in_week']), '@count hour', '@count hours') .'</span>' );
    $content .= '</div>';

    // TOTAL TRACKED DURATION
    $content .= '<div class="stormfields stormfield-tracked-duration-total">';
    $content .= theme('storm_view_item', t('Tracked duration total'), '<span class="'. $class .'">'. format_plural(theme('storm_contrib_common_number_format', $result['tracking_duration_total']), '@count hour', '@count hours') .'</span>' );
    $content .= '</div>';

    // TOTAL TRACKED BILLING DURATION
    $content .= '<div class="stormfields stormfield-tracked-duration-total-billable">';
    $content .= theme('storm_view_item', t('Tracked billable duration total'), '<span class="'. $class .'">'. format_plural(theme('storm_contrib_common_number_format', $result['tracking_billing_duration_total']), '@count hour', '@count hours') .'</span>' );
    $content .= '</div>';

    // TRACKING TIME / WORK TIME RATIO
    $ratio_limit = stormtimetracking_extension_get_timetracking_work_time_ratio();
    if ($result['balance_result']['percentage'] < $ratio_limit) {
      $class = 'balance-error';
    }
    $content .= '<div class="stormfields stormfield-tracked-work-ratio">';
    $content .= theme('storm_view_item', t('Tracking/work time ratio'), '<span class="'. $class .'">'. theme('storm_contrib_common_number_format', $result['balance_result']['percentage']) .'%</span>' );
    $content .= '</div>';

    // WORK TIME LEFT
    $content .= '<div class="stormfields stormfield-tracked-time-left">';
    $content .= theme('storm_view_item', t('Work time left'), '<span class="'. $class .'">'. format_plural(theme('storm_contrib_common_number_format', $result['balance_result']['time_left_in_hours']), '@count hour', '@count hours') .'</span>' );
    $content .= '</div>';

    $class = 'balance-ok';

    $content .= "<br />\n";

    // LAST UPDATED
    $content .= '<div class="stormfields stormfield-last-update">';
    $content .= theme('storm_view_item', t('Last updated'), '<span class="'. $class .'">'. storm_contrib_common_time_to_date($result['total_last_updated'], storm_contrib_common_get_custom_display_date_format() .' H:i:s' ) .'</span>' );
    $content .= '</div>';


    $content .= "<br />\n";

    $content .= theme("stormtimetracking_extension_person_statistic_table", $result);
  }


  // EXPORT
  if (module_exists('storm_exports')) {

    // IF EXPORT BUTTON WAS PRESSED
    if (!empty($_SESSION['storm_exports_export_'. request_uri() ])) {
      $vars['filename'] = 'person-weekly-timetracking-statistic';
      $vars['header'] = $GLOBALS['storm_exports_export_header'];
      $vars['rows'] = $GLOBALS['storm_exports_export_rows'];
      storm_exports_export($vars);
    }

  }

  return $content;
}

/**
 * thme timetrackings of person
 *
 * @param unknown_type $trackings
 * @param unknown_type $date
 * @return unknown_type
 */
function theme_stormtimetracking_extension_daily_person_timetrackings($node, $result, $year, $month, $day) {

  drupal_add_css(drupal_get_path('module', 'stormtimetracking_extension') .'/stormtimetracking_extension.css');

  $content = '';

  if (!empty($year) && !empty($month)) {
    $content .= '<div class="stormtimetracking-extension-display-type-timetrackings">';
    $content .= '<strong>'. t('Timetracking statistic for @date.', array('@date' => storm_contrib_common_time_to_date(storm_contrib_common_date_to_time($year .'-'. $month .'-'. $day), storm_contrib_common_get_custom_display_date_format()))) .'</strong>';
    $content .= '</div>';
  }

  if (!empty($result)) {

    $class = 'balance-ok';

    $content .= "<br />\n";
    $hide_info = FALSE;

    // WEEKEND
    if ('weekend' == $result['weekend']) {
      $class = 'balance-error';
      $content .= '<div class="stormfields stormfield-weekend">';
      $content .= theme('storm_view_item', t('Weekend'), '<span class="'. $class .'">'. t('This is a weekend day') .'</span>' );
      $content .= '</div>';
      $class = 'balance-ok';
      $hide_info = TRUE;
    }

    // NATIONAL HOLIDAY
    if ('national_holiday' == $result['holiday']) {
      $class = 'balance-error';
      $content .= '<div class="stormfields stormfield-holiday">';
      $content .= theme('storm_view_item', t('Holiday'), '<span class="'. $class .'">'. t('This is a national holiday') .'</span>' );
      $content .= '</div>';
      $class = 'balance-ok';
      $hide_info = TRUE;
    }

    // FULL DAY HOLIDAY
    if ('full_day_holiday' == $result['holiday']) {
      $class = 'balance-error';
      $content .= '<div class="stormfields stormfield-holiday">';
      $content .= theme('storm_view_item', t('Holiday'), '<span class="'. $class .'">'. t('Person has holiday on @date.', array('@date' => storm_contrib_common_time_to_date(storm_contrib_common_date_to_time($year .'-'. $month .'-'. $day), storm_contrib_common_get_custom_display_date_format()))) .'</span>' );
      $content .= '</div>';
      $hide_info = TRUE;
    }

    // HALF DAY HOLIDAY
    if ('half_day_holiday' == $result['holiday']) {
      $class = 'balance-error';
      $content .= '<div class="stormfields stormfield-holiday">';
      $content .= theme('storm_view_item', t('Holiday'), '<span class="'. $class .'">'. t('Person has a half day holiday on @date.', array('@date' => storm_contrib_common_time_to_date(storm_contrib_common_date_to_time($year .'-'. $month .'-'. $day), storm_contrib_common_get_custom_display_date_format()))) .'</span>' );
      $content .= '</div>';
      $class = 'balance-ok';
      $hide_info = TRUE;
    }

    // PERSON DOES NOT WORK ON THIS WEEK DAY
    if (!empty($result['not_a_working_day'])) {
      $class = 'balance-error';
      $content .= '<div class="stormfields stormfield-holiday">';
      $content .= theme('storm_view_item', t('Not a working day'), '<span class="'. $class .'">'. t('The person normally does not work on @values.', array('@value' => date('l', storm_contrib_common_date_to_time($year .'-'. $month .'-'. $day)))) .'</span>' );
      $content .= '</div>';
      $class = 'balance-ok';
      $hide_info = TRUE;
    }

    if (!$hide_info || !empty($result['tracking_duration_total'])) {
      $content .= '<div class="stormfields stormfield-total">';
      $content .= theme('storm_view_item', t('Total'), '<span class="'. $class .'">'. theme('storm_contrib_common_format_plural_duration', $result['balance_result']['working_hours'], 'hour') .'</span>' );
      $content .= '</div>';

      // TOTAL TRACKED DURATION
      $content .= '<div class="stormfields stormfield-tracked-duration">';
      $content .= theme('storm_view_item', t('Tracked duration total'), '<span class="'. $class .'">'. format_plural(theme('storm_contrib_common_number_format', $result['tracking_duration_total']), '@count hour', '@count hours') .'</span>'  );
      $content .= '</div>';

      // TOTAL TRACKED BILLABLE DURATION
      $content .= '<div class="stormfields stormfield-tracked-duration-total-billable">';
      $content .= theme('storm_view_item', t('Tracked billable duration total'), '<span class="'. $class .'">'. format_plural(theme('storm_contrib_common_number_format', $result['tracking_billing_duration_total']), '@count hour', '@count hours') .'</span>'  );
      $content .= '</div>';

      // TRACKING TIME / WORK TIME RATIO
      $ratio_limit = stormtimetracking_extension_get_timetracking_work_time_ratio();
      if ($result['balance_result']['percentage'] < $ratio_limit) {
        $class = 'balance-error';
      }
      $content .= '<div class="stormfields stormfield-tracked-work-ratio">';
      $content .= theme('storm_view_item', t('Tracking/work time ratio'), '<span class="'. $class .'">'. theme('storm_contrib_common_number_format', $result['balance_result']['percentage']) .'%</span>'  );
      $content .= '</div>';

      // WORK TIME LEFT
      $content .= '<div class="stormfields stormfield-tracked-time-left">';
      $content .= theme('storm_view_item', t('Work time left'), '<span class="'. $class .'">'. format_plural(theme('storm_contrib_common_number_format', $result['balance_result']['time_left_in_hours']), '@count hour', '@count hours') .'</span>'  );
      $content .= '</div>';

      $class = 'balance-ok';

      // LAST UPDATE
      if (!empty($result['total_last_updated'])) {
        $content .= '<div class="stormfields stormfield-last-update">';
        $content .= theme('storm_view_item', t('Last updated'), '<span class="'. $class .'">'. storm_contrib_common_time_to_date($result['total_last_updated'], storm_contrib_common_get_custom_display_date_format() .' H:i:s' ) .'</span>' );
        $content .= '</div>';
      }
    }

    $content .= "<br />\n";

    $content .= theme("stormtimetracking_extension_person_statistic_table", $result);
  }

  // EXPORT
  if (module_exists('storm_exports')) {

    // IF EXPORT BUTTON WAS PRESSED
    if (!empty($_SESSION['storm_exports_export_'. request_uri() ])) {
      $vars['filename'] = 'person-daily-timetracking-statistic';
      $vars['header'] = $GLOBALS['storm_exports_export_header'];
      $vars['rows'] = $GLOBALS['storm_exports_export_rows'];
      storm_exports_export($vars);
    }

  }

  return $content;
}


/**
 * theme timetrackings of type stormproject, stormtask, stormticket
 *
 * @param unknown_type $trackings
 * @param unknown_type $date
 * @return unknown_type
 */
function theme_stormtimetracking_extension_display_type_timetrackings($node, $trackings, $time_start = 0, $time_end = 0) {

  drupal_add_css(drupal_get_path('module', 'stormtimetracking_extension') .'/stormtimetracking_extension.css');

  $content = '';
  if (!empty($time_start)) {
    $content .= '<div class="stormtimetracking-extension-display-type-timetrackings">';
    $content .= '<strong>'. t('Timetrackings between: @start and @end', array('@start' => $time_start, '@end' => $time_end)) .'</strong>';
    $content .= '</div>';
  }
  else {
    $content .= '<div class="stormtimetracking-extension-display-type-timetrackings">';
    $content .= '<strong>'. t('Timetrackings') .'</strong>';
    $content .= '</div>';
  }

  $content .= '<div class="stormtimetracking-extension-display-type-timetrackings-add-icon">';
  $content .= $trackings['add_icon'];
  $content .= '</div>';


  if (!empty($trackings)) {

    $class = 'balance-ok';

    $content .= "<br />\n";

    $content .= '<div class="stormfields stormfield-total">';
    $content .= theme('storm_view_item', t('Total'), '' );
    $content .= '</div>';

    $content .= '<div class="stormfields stormfield-tracked-duration-total">';
    $content .= theme('storm_view_item', t('Tracked duration total'), theme('storm_contrib_common_format_plural_duration', $trackings['total_duration_in_hours'], 'hour') );
    $content .= '</div>';

    if (!empty($node->total_real_timetracking_costs)) {
      $content .= '<div class="stormfields stormfield-tracked-costs">';
      $content .= theme('storm_view_item', t('Total tracking costs'), theme('storm_contrib_common_number_format', $node->total_real_timetracking_costs) .' '. $node->total_real_timetracking_costs_currency );
      $content .= '</div>';
    }

    $content .= "<br />\n";

    // TODO BILLABLE COSTS

    // IF EXPORT BUTTON WAS PRESSED
    if (!empty($_SESSION['storm_exports_export_'. request_uri() ])) {
      $header_txt_duration = t('Duration in hours');
    }
    else {
      $header_txt_duration = t('Duration');
    }

    if (!empty($trackings['total_costs'])) {
      $header = array(
        array('data' => t('Date')),
        array('data' => t('Time')),
        array('data' => $header_txt_duration),
        array('data' => t('Person')),
        array('data' => t('Title')),
        array('data' => t('Tracked on')),
        array('data' => t('Costs')),
      );
    }
    else {
      $header = array(
        array('data' => t('Date')),
        array('data' => t('Time')),
        array('data' => $header_txt_duration),
        array('data' => t('Person')),
        array('data' => t('Title')),
        array('data' => t('Tracked on')),
      );
    }

    $rows = array();

    // --------
    // TOTAL
    // --------
    $row = array();
    if (!empty($_SESSION['storm_exports_export_'. request_uri() ])) {
      $row[] = array('data' => '<strong>'. t("Total") .'</strong>');
    }
    else {
      $row[] = array('data' => '<strong>'. t("Total <br />\n (this page)") .'</strong>');
    }
    $row[] = array('data' => ' ');
    $row[] = array('data' => '<strong>'. theme('storm_contrib_common_format_plural_duration', $trackings['duration_in_hours'], 'hour') .'</strong>');
    $row[] = array('data' => ' ');
    $row[] = array('data' => ' ');
    $row[] = array('data' => ' ');
    if (!empty($trackings['total_costs'])) {
      $row[] = array('data' => '<strong>'. theme('storm_contrib_common_number_format', $trackings['total_costs']) .' '. $trackings['total_costs_currency'] .'</strong>');
    }
    $rows[] = $row;

    foreach ($trackings as $nid => $tracking_array) {

      if (is_numeric($nid) && !empty($tracking_array)) {

        if (!empty($tracking_array['ticket_nid'])) {
          $type = 'ticket';
        }
        elseif (!empty($tracking_array['task_nid'])) {
          $type = 'task';
        }
        else {
          $type = 'project';
        }

        $row = array();
        $row[] = array('data' => date(storm_contrib_common_get_custom_display_date_format(), $tracking_array['trackingdate']));
        $row[] = array('data' => $tracking_array['timebegin'] .'-'. $tracking_array['timeend']);
        $row[] = array('data' => theme('storm_contrib_common_format_plural_duration', $tracking_array['duration'], 'hour'));
        $row[] = array('data' => l($tracking_array['person_name'], 'node/'. $tracking_array['person_nid']));
        $row[] = array('data' => l($tracking_array['title'], 'node/'. $tracking_array['nid']));
        $row[] = array('data' => l($tracking_array[$type .'_title'], 'node/'. $tracking_array[$type .'_nid']) .' ('. ucfirst($type) .')');
        if (!empty($tracking_array['timetracking_costs']) && !empty($trackings['total_costs'])) {
          $row[] = array('data' => theme('storm_contrib_common_number_format', $tracking_array['timetracking_costs']) .' '. $tracking_array['timetracking_costs_currency']);
        }
        elseif (empty($tracking_array['timetracking_costs']) && !empty($trackings['total_costs'])) {
          $row[] = array('data' => theme('storm_contrib_common_number_format', 0) .' '. $trackings['total_costs_currency']);
        }
        $rows[] = array('data' => $row);

      }

    }

    if (!empty($rows)) {
      $content .= theme('table', $header, $rows);
      if (!empty($trackings['pager'])) {
        $content .= $trackings['pager'];
      }
    }


  }
  else {
    $content .= '<div class="stormtimetracking-extension-display-type-timetrackings-no-data">';
    $content .= t('No timetrackings available');
    $content .= '</div>';
  }


  // EXPORT
  if (module_exists('storm_exports')) {

    // IF EXPORT BUTTON WAS PRESSED
    if (!empty($_SESSION['storm_exports_export_'. request_uri() ])) {
      $vars['filename'] = 'timetrackings-of-project';
      $vars['header'] = $header;
      $vars['rows'] = $rows;
      storm_exports_export($vars);
    }

  }

  return $content;
}



/**
 * thme timetrackings of person
 *
 * @param unknown_type $trackings
 * @param unknown_type $date
 * @return unknown_type
 */
function theme_stormtimetracking_extension_display_timetrackings_report_by_projects($report, $months, $year, $month) {

  drupal_add_css(drupal_get_path('module', 'stormtimetracking_extension') .'/stormtimetracking_extension.css');

  $content = '';

  if (!empty($year) && !empty($month)) {
    $content .= '<div class="stormtimetracking-extension-display-type-timetrackings">';
    $content .= '<strong>'. t('Timetracking statstic for @month @year', array('@month' => $months[$month], '@year' => $year)) .'</strong>';
    $content .= '</div>';
  }

  if (!empty($report)) {

    // IF EXPORT BUTTON WAS PRESSED
    if (!empty($_SESSION['storm_exports_export_'. request_uri() ])) {
      $header_txt_duration = t('Duration in hours');
    }
    else {
      $header_txt_duration = t('Duration');
    }

    if (!empty($report['costs_total']) || 0 == $report['costs_total']) {

      $header = array(
        array('data' => t('Organization')),
        array('data' => t('Project')),
        array('data' => $header_txt_duration),
        array('data' => t('Billable duration')),
        array('data' => t('Billable duration costs')),
        array('data' => t('Total Costs')),
      );
    }
    else {
      $header = array(
        array('data' => t('Organization')),
        array('data' => t('Project')),
        array('data' => $header_txt_duration),
        array('data' => t('Billable duration')),
      );
    }

    $rows = array();

    // ------
    // TOTAL
    // ------
    $row = array();
    $row[] = array('data' => '<strong>'. t('Total') .'</strong>');
    $row[] = array('data' => ' ');
    $row[] = array('data' => '<strong>'. theme('storm_contrib_common_format_plural_duration', $report['tracking_duration_total'], 'hour') .'</strong>');
    $row[] = array('data' => '<strong>'. theme('storm_contrib_common_format_plural_duration', $report['tracking_billing_duration_total'], 'hour') .'</strong>');
    if (!empty($report['billing_costs_total']) || 0 == $report['billing_costs_total']) {
      $row[] = array('data' => '<strong>'. theme('storm_contrib_common_number_format', $report['billing_costs_total']) .' '. $report['billing_costs_currency_total'] .'</strong>');
    }
    if (!empty($report['costs_total']) || 0 == $report['costs_total']) {
      $row[] = array('data' => '<strong>'. theme('storm_contrib_common_number_format', $report['costs_total']) .' '. $report['costs_currency_total'] .'</strong>');
    }
    $rows[] = $row;

    foreach ($report['trackings'] as $nid_organization => $organization_array) {
      foreach ($organization_array['projects'] as $nid_project => $tracking_array) {

        $row = array();

        // ORGANIZATION
        if (!empty($organization_array['nid_organization']) && is_numeric($organization_array['nid_organization'])) {
          $row[] = array('data' => l($organization_array['organization_title'], 'node/'. $organization_array['nid_organization']));
        }
        else {
          $row[] = array('data' => $organization_array['organization_title']);
        }

        // PROJECT
        if (empty($tracking_array['project_title'])) {
          $tracking_array['project_title'] = t('no project');
        }
        if (!empty($nid_project) && is_numeric($nid_project)) {
          $row[] = array('data' => l($tracking_array['project_title'], 'node/'. $nid_project));
        }
        else {
          $row[] = array('data' => $tracking_array['project_title']);
        }

        // DURATION
        $row[] = array('data' => theme('storm_contrib_common_format_plural_duration', $tracking_array['tracking_duration'], 'hour'));

        // BILLING DURATION
        $row[] = array('data' => theme('storm_contrib_common_format_plural_duration', $tracking_array['tracking_billing_duration'], 'hour'));

        // BILLING DURATION COSTS
        if (!empty($tracking_array['billing_duration_costs']) || 0 == $tracking_array['billing_duration_costs']) {
          $row[] = array('data' => theme('storm_contrib_common_number_format', $tracking_array['billing_duration_costs']) .' '. $tracking_array['billing_duration_costs_currency'] );
        }
        else {
          $row[] = array('data' => t('Access to project billing costs not permitted'));
        }

        // TOTAL COSTS
        if (!empty($tracking_array['duration_costs']) || 0 == $tracking_array['duration_costs']) {
          $row[] = array('data' => theme('storm_contrib_common_number_format', $tracking_array['duration_costs']) .' '. $tracking_array['duration_costs_currency'] );
        }
        else {
          $row[] = array('data' => t('Access to project costs not permitted'));
        }

        $rows[] = array('data' => $row);
      }
    }

    if (!empty($rows)) {
      $content .= theme('table', $header, $rows);
    }


  }
  else {
    $content .= '<div class="stormtimetracking-extension-display-type-timetrackings-no-data">';
    $content .= t('No timetrackings available');
    $content .= '</div>';
  }


  // EXPORT
  if (module_exists('storm_exports')) {

    // IF EXPORT BUTTON WAS PRESSED
    if (!empty($_SESSION['storm_exports_export_'. request_uri() ])) {
      $vars['filename'] = 'monthly-timetrackings-report-'. $year .'-'. $months[$month];
      $vars['header'] = $header;
      $vars['rows'] = $rows;
      storm_exports_export($vars);
    }

  }

  return $content;
}


/**
 * theme displaying of timetracking report by projects and persons
 *
 * @param unknown_type $report
 * @param unknown_type $report_persons
 * @param unknown_type $months
 * @param unknown_type $year
 * @param unknown_type $month
 */
function theme_stormtimetracking_extension_display_timetrackings_report_by_persons($report, $report_persons, $months, $year, $month) {

  $content = '';

  if (!empty($year) && !empty($month)) {
    $content .= '<div class="stormtimetracking-extension-display-type-timetrackings">';
    $content .= '<strong>'. t('Timetracking statstic for @month @year', array('@month' => $months[$month], '@year' => $year)) .'</strong>';
    // IF EXPORT
    if (!empty($_SESSION['storm_exports_export_'. request_uri() ])) {
      $content .= '<strong>'. t('All values are displayed in hours') .'</strong>';
    }
    $content .= '</div>';
  }

  $row_head = array();
  $row_total = array();
  $rows = array();

  // IF EXPORT
  if (!empty($_SESSION['storm_exports_export_'. request_uri() ])) {
    $row_head[] = array('data' => t('Organization'));
    $row_head[] = array('data' => t('Project'));
  }
  else {
    $row_head[] = array('data' => '<strong>'. t('Organization') .'</strong>');
    $row_head[] = array('data' => '<strong>'. t('Project') .'</strong>');
  }

  $row_total[] = array('data' => ' ');

  // IF EXPORT
  if (!empty($_SESSION['storm_exports_export_'. request_uri() ])) {
    $row_total[] = array('data' => t('Total'));
  }
  else {
    $row_total[] = array('data' => '<strong>'. t('Total') .'</strong>');
  }

  $cntr = 0;


  // EACH ORGANIZATION
  if (!empty($report)) {
    $last_organization = '';
    foreach ($report as $nid_organization => $organization_array) {

      if (empty($nid_organization)) {
        $nid_organization = 0;
      }


      // EACH PROJECT
      if (!empty($organization_array['projects']) && is_array($organization_array['projects'])) {
        foreach ($organization_array['projects'] as $project_nid => $project_array) {

          if (empty($project_nid)) {
            $project_nid = 0;
          }

          $cntr++;

          $row = array();

          // NAME OF THE ORGANIZATION
          // IF EXPORT
          if (!empty($_SESSION['storm_exports_export_'. request_uri() ])) {
            $row[] = array('data' => $organization_array['title']);
          }
          else {
            if (!empty($organization_array['nid'])) {
              $row[] = array('data' => l($organization_array['title'], 'node/'. $organization_array['nid']));
            }
            else {
              $row[] = array('data' => $organization_array['title']);
            }
          }


          // NAME OF THE PROJECT
          if (empty($project_array['project_nid'])) {
            $project_array['project_title'] = t('no project');
          }
          // IF EXPORT
          if (!empty($_SESSION['storm_exports_export_'. request_uri() ])) {
            $row[] = array('data' => $project_array['project_title']);
          }
          else {
            if (!empty($project_array['project_nid'])) {
              $row[] = array('data' => l($project_array['project_title'], 'node/'. $project_array['project_nid']));
            }
            else {
              $row[] = array('data' => $project_array['project_title']);
            }

          }

          // FOR EACH PERSON
          if (!empty($report_persons)) {

            foreach ($report_persons as $nid_person => $person_array) {

              // -----------------------------------
              // NAME OF THE PERSONS IN TABLE HEAD
              // -----------------------------------
              if (1 == $cntr) {

                // IF EXPORT
                if (!empty($_SESSION['storm_exports_export_'. request_uri() ])) {
                  $row_head[] = array('data' => $person_array['person_title']);

                }
                else {
                  $row_head[] = array('data' => l($person_array['person_title'], 'node/'. $nid_person ));
                }

                // ------------------------------
                // TOTAL PERSONS TIMETRACKINGS
                // ------------------------------
                if (!empty($person_array['total_person_project_tracking_duration'])) {
                  $value = $person_array['total_person_project_tracking_duration'];
                }
                else {
                  $value = 0;
                }
                $row_total[] = array('data' => theme('storm_contrib_common_format_plural_duration', $value, 'hour'));

              }

              // --------------------------------------------------
              // TRACKING DURATION OF PERSON FOR PROJECT IN HOURS
              // --------------------------------------------------

              if (!empty($person_array[$nid_organization]['projects'][$project_nid]['person_project_tracking_duration'])) {
                $value = $person_array[$nid_organization]['projects'][$project_nid]['person_project_tracking_duration'];
              }
              else {
                $value = 0;
              }
              $row[] = array('data' => theme('storm_contrib_common_format_plural_duration', $value, 'hour'));

            }
          }

          if (1 == $cntr) {
            // IF EXPORT
            if (!empty($_SESSION['storm_exports_export_'. request_uri() ])) {
              $row_head[] = array('data' => t('Total'));
            }
            else {
              $row_head[] = array('data' => '<strong>'. t('Total') .'</strong>');
            }
          }


          // -------------------------------
          // TOTAL PROJECTS TIMETRACKINGS
          // -------------------------------

          // TOTAL TRACKING DURATION OF PERSON IN HOURS
          if (!empty($report[$nid_organization]['projects'][$project_nid]['total_project_tracking_duration'])) {
            $value = $report[$nid_organization]['projects'][$project_nid]['total_project_tracking_duration'];
          }
          else {
            $value = 0;
          }
          $row[] = array('data' => theme('storm_contrib_common_format_plural_duration', $value, 'hour'));


          // TABLE HEAD
          if (1 == $cntr) {
            $rows[] = array('data' => $row_head);
          }

          $rows[] = array('data' => $row);


        }
      }


    }
  }

  $header = array();

  if (!empty($rows)) {

    // TOTAL
    $rows[] = array('data' => $row_total);

    // EXPORT
    if (module_exists('storm_exports')) {

      // IF EXPORT BUTTON WAS PRESSED
      if (!empty($_SESSION['storm_exports_export_'. request_uri() ])) {
        $vars['filename'] = 'monthly_timetrackings_report_by_persons';
        $vars['header'] = $header;
        $vars['rows'] = $rows;
        storm_exports_export($vars);
      }

    }

    // HEADER IS NOT WORKING BECAUSE OF TOO MANY COLUMNS
    $content .= theme('table', $header, $rows);
  }


  return $content;
}


function theme_stormtimetracking_extension_calendar_mini_datebox($cell, $node_person, $mini) {
  $day_num = intval(substr($cell['date'], 8, 2));
  if ($mini) {
    $class = "mini-day-on";
  }
  else {
    $class = "day";
  }
  return '<div class="month '.$class.'">'.l($day_num, 'node/'.$node_person->nid.'/timetrackings', array('query' => 'date='.$cell['date'])).'</div>';
}

function theme_stormtimetracking_extension_calendar_mini_timetracking_percentage($percentage, $mini) {
  if ($mini) {
    return '<span class="stormtimetracking-extension-percentage">'.$percentage.'</span>';
  }
  else {
    return '<span class="stormtimetracking-extension-percentage">'.t('Tracked time: %per', array('%per' => $percentage)).'</span>';
  }
}

function theme_stormtimetracking_extension_person_statistic_table($result) {
  $content = '';
    if (!empty($result['trackings'])) {

      // IF EXPORT BUTTON WAS PRESSED
      if (!empty($_SESSION['storm_exports_export_'. request_uri() ])) {
        $header_txt_duration = t('Duration in hours');
      }
      else {
        $header_txt_duration = t('Duration');
      }

      $extended = FALSE;
      if (!empty($result['costs_total'])) {
        $header = array(
          array('data' => t('Organization')),
          array('data' => t('Project')),
          array('data' => $header_txt_duration),
          array('data' => t('Billable duration')),
          array('data' => t('Billable duration costs')),
          array('data' => t('Total Costs')),
        );
        $extended = TRUE;
      }
      else {
        $header = array(
          array('data' => t('Organization')),
          array('data' => t('Project')),
          array('data' => $header_txt_duration),
          array('data' => t('Billable duration')),
        );
      }

      $rows = array();

      // -------
      // TOTAL
      // -------
      $row = array();
      $row[] = array('data' => '<strong>'. t('Total') .'</strong>');
       $row[] = array('data' => ' ');
      $row[] = array('data' => '<strong>'. theme('storm_contrib_common_format_plural_duration', $result['tracking_duration_total'], 'hour') .'</strong>');
      $row[] = array('data' => '<strong>'. theme('storm_contrib_common_format_plural_duration', $result['tracking_billing_duration_total'], 'hour') .'</strong>');
      if ($extended) {
        $row[] = array('data' => '<strong>'. theme('storm_contrib_common_number_format', $result['billing_costs_total']) .' '. $result['billing_costs_currency_total'] .'</strong>');
        $row[] = array('data' => '<strong>'. theme('storm_contrib_common_number_format', $result['costs_total']) .' '. $result['costs_currency_total'] .'</strong>');
      }
      $rows[] = $row;

      foreach ($result['trackings'] as $nid_organization => $organization_array) {
        foreach ($organization_array['projects'] as $nid_project => $tracking_array) {
          $row = array();

          // ORGANIZATION
          if (!empty($nid_organization) && is_numeric($nid_organization)) {
            $row[] = array('data' => l($organization_array['organization_title'], 'node/'. $nid_organization));
          }
          else {
            $row[] = array('data' => $organization_array['organization_title']);
          }

          // TITLE
          if (empty($tracking_array['project_title'])) {
            $tracking_array['project_title'] = t('no project');
          }
          if (!empty($nid_project) && is_numeric($nid_project)) {
            $row[] = array('data' => l($tracking_array['project_title'], 'node/'. $nid_project));
          }
          else {
            $row[] = array('data' => $tracking_array['project_title']);
          }

          // DURATION
          $row[] = array('data' => theme('storm_contrib_common_format_plural_duration', $tracking_array['tracking_duration'], 'hour'));

          // BILLING DURATION
          $row[] = array('data' => theme('storm_contrib_common_format_plural_duration', $tracking_array['tracking_billing_duration'], 'hour'));

          // BILLING DURATION COSTS
          if ((!empty($tracking_array['billing_duration_costs']) || 0 == $tracking_array['billing_duration_costs']) && $extended) {
            $row[] = array('data' => theme('storm_contrib_common_number_format', $tracking_array['billing_duration_costs']) .' '. $tracking_array['billing_duration_costs_currency'] );
          }
          elseif (empty($tracking_array['billing_duration_costs']) && !empty($result['costs_total'])) {
            $row[] = array('data' => t('Access to project costs not permitted'));
          }

          // DURATION COSTS
          if ((!empty($tracking_array['duration_costs']) || 0 == $tracking_array['duration_costs']) && $extended) {
            $row[] = array('data' => theme('storm_contrib_common_number_format', $tracking_array['duration_costs']) .' '. $tracking_array['duration_costs_currency'] );
          }
          elseif (empty($tracking_array['duration_costs']) && !empty($result['costs_total'])) {
            $row[] = array('data' => t('Access to project costs not permitted'));
          }
          $rows[] = array('data' => $row);
        }
      }

    if (!empty($rows)) {
      // IF EXPORT BUTTON WAS PRESSED
      if (!empty($_SESSION['storm_exports_export_'. request_uri() ])) {
        $GLOBALS['storm_exports_export_header'] = $header;
        $GLOBALS['storm_exports_export_rows'] = $rows;
      }
      else {
        $content .= theme('table', $header, $rows);
      }
    }
  }
  else {
    $content .= '<div class="stormtimetracking-extension-display-type-timetrackings-no-data">';
    $content .= t('No timetrackings available');
    $content .= '</div>';
  }
  return $content;
}

/**
 * theme storm reports dashboard
 * @return unknown_type
 */
function theme_stormtimetracking_extension_storm_reports_dashboard($link_blocks) {

  $content = '';

  $content .= '<div id="stormdashboard">';

  if (!empty($link_blocks)) {

    $content .= '<dl class="stormdashboard">';

    foreach ($link_blocks as $block_id => $link_block_array) {

      $content .= '<div class="stormdashboard">';

      if (!empty($link_block_array)) {
        foreach ($link_block_array as $key => $link_array) {
          $content .= theme($link_array['theme'], $link_array);
        }
      }

      $content .= '</div>';

    }

    $content .= '</dl>';

  }
  else {
    $content .= t('No reports available');
  }

  $content .= '</div>';

  return $content;
}


/**
 * theme storm extension reports dashboard link
 *
 * @param unknown_type $source_module
 * @param unknown_type $destination_module
 * @param unknown_type $node_nid
 * @param unknown_type $weight
 * @return unknown_type
 */
function theme_stormtimetracking_extension_storm_reports_dashboard_link($link_array) {

  $content = '';

  // DEFAULT ICON
  if (empty($link_array['icon'])) {
    $dt_id = 'stormexpenses';
  }
  else {
    $dt_id = $link_array['icon'];
  }

  if (variable_get('storm_icons_display', TRUE)) {
    $content .= '<dt id="'. $dt_id .'" class="stormcomponent">';
  }
  else {
    $content .= '<dt class="stormcomponent">';
  }

  $content .= l($link_array['title'], $link_array['path'], $link_array['params']);

  $content .= '</dt>';

  return $content;
}